@@ -19,8 +19,6 @@ import dnf.logging
 import dnf.subject
 import dnf.yum.rpmtrans
 
-from dnf.cli.cli import Cli
-
 from . import packager
 
 
@@ -339,9 +337,15 @@ class MiniDNF():
         # and either install an older version or do nothing.
         base.conf.best = True
 
-        base.init_plugins(disabled_glob=self._disabledPlugins, cli=Cli(base))
-
+        base.conf.read(priority=dnf.conf.PRIO_MAINCONFIG)
+        base.conf.substitutions.update_from_etc(
+            base.conf.installroot,
+            varsdir=base.conf.varsdir,
+        )
+        base.init_plugins(disabled_glob=self._disabledPlugins)
+        base.pre_configure_plugins()
         base.read_all_repos()
+        base.configure_plugins()
         base.repos.all().set_progress_bar(self._MyDownloadProgress(self._sink))
 
         # dnf does not keep packages for offline usage
@@ -836,6 +840,29 @@ class MiniDNF():
             if _base is not None:
                 self._destroyBase(_base)
 
+    def getConf(self):
+        we_created_base = False
+        if self._base is None:
+            base = self._createBase()
+            we_created_base = True
+        else:
+            base = self._base
+
+        try:
+            return 'DNF Conf dump:\n{conf}\n{repos}'.format(
+                conf=base.conf.dump(),
+                repos=''.join(
+                    f'DNF Repo dump: {repo.repofile}\n{repo.dump()}\n'
+                    for repo in base.repos.values()
+                )
+            )
+        except Exception as e:
+            self._sink.error(e)
+            raise
+        finally:
+            if we_created_base and base is not None:
+                self._destroyBase(base)
+
 
 class Example():
 
